import sys
import typing


def check_file_type(filename: str, expected_type: typing.Union[str, list]):
    """Checks if a given file has the type or types that are passed in

    Args:
        filename (str): the filename in question
        expected_type (t.Union[str, list]): either a string with the expected
        filetype or a list of strings with expected file types
    """
    # get the extension from filename

    extension = filename.rstrip().split('.')[-1].lower()
    try:
        if type(expected_type) == str:
            # lower case both the extension and expected_type, do a string match
            assert extension == expected_type.lower()
        elif type(expected_type) == list:
            assert extension in [file_type.lower() for file_type in expected_type]
        else:
            raise ValueError(f'expected string or list but received {expected_type}')
    except AssertionError:
        sys.exit(f"The pipeline is expecting the file type to be {expected_type}, but the provided file has a file type of {extension}.")



import numpy as np
from numbers import Number


def isnumber(value):
    """ Check if the target value is a number.
    
    Args:
        value ():  The input under test
    
    Returns:
        (bool): True if the target is a number. False otherwise.
    """

    # Note boolean can be converted to number so it has to be avoided
    if type(value) is bool:
        return False

    try:
        float(value)
        return True
    except:
        return False



# coding: utf-8

from setuptools import setup, find_packages

NAME = "ts-task-script-utils"
VERSION = "1.0.1"

with open("README.md", "r") as readme_file:
    readme = readme_file.read()

requirements = [
    "numpy>=1.20.1",
    "arrow>=1.0.2",
    "dateparser>=1.0.0"
]

setup(
    name=NAME,
    version=VERSION,
    description="Python utility functions for Tetra Task Scripts",
    author="tetrascience",
    author_email="developers@tetrascience.com",
    url="https://github.com/tetrascience/ts-task-script-utils",
    project_urls={
        "Tetra Developer Site": "https://developers.tetrascience.com",
    },
    keywords=[],
    install_requires=requirements,
    packages=find_packages(),
    include_package_data=True,
    long_description=readme,
    long_description_content_type="text/markdown",
    python_requires='>=3.7',
    license='Apache License 2.0',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
)



import dateparser, arrow, datetime
from dateutil import tz


def convert_datetime_to_ts_format(
    datetime, datetime_format: str = "", timezone: str = ""
):
    """ Convert datetime to TetraScience standard: ISO-8601 in milliseconds in UTC if timezone is available
    
        Inputs:
            datetime - raw datetime
            datetime_format - raw datetime format (must follow https://arrow.readthedocs.io/en/stable/#format)
            timezone - user-defined timezone. If the user specify an timezone, it will overwrite the timezone extracted from the raw datetime. It can be either string (i.e. "GMT-5") or a timezone type recognized by the arrow.get function.
            

        Output:
            Datetime string in ISO-8601 with millisecond precision. If timezone is defined, it will be in UTC indicated by 'Z'.
                
            Examples:
            If timezone is defined: "2019-07-17T14:21:00.000Z"
            If timezone is not defined: "2019-07-17T11:21:00.000"
    """

    if datetime_format:
        parsed_time = arrow.get(datetime, datetime_format)
        parser_name = "arrow"
    else:
        parsed_time = dateparser.parse(datetime)
        parser_name = "dateparser"

    if parsed_time is None:
        raise ValueError(
            f"Could not parse input datetime string {datetime} using {parser_name} and the following input formats: {datetime_format}"
        )

    timezone_to_use = parsed_time.tzinfo

    if timezone:
        try:
            timezone_to_use = tz.gettz(timezone)
        except:
            print(
                "The provided timezone can't be parsed by dateutil tz, going to use the plain value"
            )
            timezone_to_use = timezone

    datetime_iso_local = ""
    utc_indicator = ""

    if timezone_to_use:
        datetime_iso_local = arrow.get(str(parsed_time), tzinfo=timezone_to_use)
        utc_indicator = "Z"

    else:
        datetime_iso_local = arrow.get(str(parsed_time), tzinfo=tz.gettz("GMT"))

    ts_datetime = (
        datetime_iso_local.to("GMT")
        .format("YYYY-MM-DDTHH:mm:ss.SSSZ")
        .replace("+0000", utc_indicator)
    )

    return ts_datetime
